@@ -53,3 +53,37 @@ class DictionaryService:
             service=Services.dict,
             request_path=request_path
         ).get('items')
+
+    def get_tag_categories(self, service_name: str) -> dict:
+        query_params = {'service_name': service_name}
+        request_path = f"/tag_categories?{urlencode(query_params, doseq=True)}"
+        return self.service_provider.fetch_data(
+            service=Services.dict,
+            request_path=request_path
+        )
+
+    def get_tag_category(self, tag_category_id: str) -> dict:
+        request_path = f"/tag_categories/{tag_category_id}"
+        return self.service_provider.fetch_data(
+            service=Services.dict,
+            request_path=request_path
+        )
+
+    def get_tags(self, search: str = None, is_active: bool = None) -> dict:
+        query_params = {}
+        if search:
+            query_params['search'] = search
+        if is_active is not None:
+            query_params['is_active'] = is_active
+        request_path = f"/tags?{urlencode(query_params)}"
+        return self.service_provider.fetch_data(
+            service=Services.dict,
+            request_path=request_path
+        )
+
+    def get_tag(self, tag_id: str) -> dict:
+        request_path = f"/tags/{tag_id}"
+        return self.service_provider.fetch_data(
+            service=Services.dict,
+            request_path=request_path
+        )
